import React, { ReactNode } from 'react';
import { FilterValue, TextFilterProps } from './TextFilter';
import { RadioFilterProps } from './RadioFilter';
import { CheckboxFilterProps } from './CheckboxFilter';
import { GroupFilterProps } from './GroupFilter';
import './conditional-filter.scss';
export type FilterValues = TextInputProps & RadioFilterProps & CheckboxFilterProps & GroupFilterProps & {
    items?: FilterValue[];
};
export interface TextInputProps {
    id?: string;
    onChange?: (e: React.MouseEvent | React.ChangeEvent | React.FormEvent<HTMLInputElement>, selection?: number | string) => void;
    placeholder?: string;
    value?: string;
}
export type ConditionalFilterItem = {
    id?: string;
    label?: ReactNode;
    placeholder?: string;
    value?: string;
} & ({
    type: 'checkbox';
    filterValues: CheckboxFilterProps;
} | {
    type: 'text';
    filterValues: TextFilterProps;
} | {
    type: 'radio';
    filterValues: RadioFilterProps;
} | {
    type: 'group';
    filterValues: GroupFilterProps;
} | {
    type: 'singleSelect';
    filterValues: RadioFilterProps;
} | {
    type: 'custom';
    filterValues: Record<string, any>;
});
export interface ConditionalFilterProps<R extends HTMLElement = NonNullable<any>> extends TextInputProps {
    hideLabel?: boolean;
    items: ConditionalFilterItem[];
    id?: string;
    isDisabled?: boolean;
    innerRef?: React.RefObject<R>;
}
declare const ConditionalFilter: React.FunctionComponent<ConditionalFilterProps>;
export default ConditionalFilter;
