import React, { ChangeEvent, ReactNode } from 'react';
import GroupType from './groupType';
import { ButtonProps } from '@patternfly/react-core/dist/dynamic/components/Button';
import { ButtonVariant } from '@patternfly/react-core/dist/dynamic/components/Button';
import { CheckboxProps } from '@patternfly/react-core/dist/dynamic/components/Checkbox';
import { RadioProps } from '@patternfly/react-core/dist/dynamic/components/Radio';
export interface GroupItem {
    isSelected?: boolean;
    group: Group;
    item: GroupFilterItem;
}
export interface Group {
    groupSelectable?: boolean;
    id?: string;
    isSelected?: boolean;
    item?: GroupFilterItem;
    items?: GroupFilterItem[];
    label: string;
    noFilter?: boolean;
    type?: GroupType;
    value?: string;
}
type ExtraCheckboxAttributes = {
    type: GroupType.checkbox;
    onChange?: CheckboxProps['onChange'];
    onClick?: CheckboxProps['onClick'];
};
type ExtraButtonAttributes = {
    type: GroupType.button;
    variant?: ButtonVariant;
    onClick?: NonNullable<ButtonProps['onClick']>;
};
type ExtraRadioAttributes = {
    type: GroupType.radio;
    isChecked?: boolean;
    onChange?: RadioProps['onChange'];
};
type ExtraTreeViewAttributes = {
    type: GroupType.treeView;
    hasCheck?: boolean;
    checkProps?: Record<string, boolean | null>;
    children: TreeViewItem[];
    label: string;
    name?: string;
};
export type GroupFilterItem = {
    className?: string;
    id?: string;
    isChecked?: boolean;
    label: ReactNode;
    name?: string;
    noFilter?: boolean;
    tagKey?: string;
    tagValue?: string;
    value: string;
    groupSelectable?: boolean;
} & (ExtraButtonAttributes | ExtraCheckboxAttributes | ExtraRadioAttributes | ExtraTreeViewAttributes | {
    type?: GroupType.plain;
});
export type TreeViewItem = GroupFilterItem & Omit<ExtraTreeViewAttributes, 'type' | 'children'> & {
    children?: TreeViewItem[];
};
export declare function isCheckboxItem(type?: GroupType, item?: GroupFilterItem): item is GroupFilterItem & ExtraCheckboxAttributes;
export declare function isButtonItem(type?: GroupType, item?: GroupFilterItem): item is GroupFilterItem & ExtraButtonAttributes;
export declare function isRadioItem(type?: GroupType, item?: GroupFilterItem): item is GroupFilterItem & ExtraRadioAttributes;
export declare function isTreeViewItem(type?: GroupType, item?: GroupFilterItem): item is GroupFilterItem & ExtraTreeViewAttributes;
export declare const isChecked: (groupValue: string, itemValue: string | number, id: string | undefined, tagValue: string | undefined, propSelected: Record<string, Record<string, boolean | GroupItem>>) => boolean;
export type FilterMenuItemOnChange = (event: React.FormEvent | React.MouseEventHandler, selected: Record<string, Record<string, GroupItem | boolean>>, selectedItem: {
    value: string;
    label: string | ReactNode;
    id: string;
    type: unknown;
    items: GroupFilterItem[];
}, item: {
    id?: string;
    value?: string;
}, value: string, itemValue: string) => void;
export declare const getMenuItems: (items: GroupFilterItem[], onChange: FilterMenuItemOnChange | undefined, calculateSelected: (type?: GroupType, groupKey?: string, value?: TreeViewItem | string, checked?: boolean) => Record<string, Record<string, boolean | GroupItem>>, groupType?: GroupType, groupValue?: string, groupLabel?: string, groupId?: string, group?: Group) => GroupFilterItem[];
export declare const convertTreeItem: (item: TreeViewItem) => TreeViewItem;
export declare const getGroupMenuItems: (groups: Group[], onChange: FilterMenuItemOnChange | undefined, calculateSelected: (type?: GroupType, groupKey?: string, value?: TreeViewItem | string, checked?: boolean) => Record<string, Record<string, boolean | GroupItem>>) => Group[];
export declare const calculateSelected: (selectedTags: Record<string, Record<string, GroupItem | boolean>>) => (type?: GroupType, groupKey?: string, value?: TreeViewItem | string, checked?: boolean) => Record<string, Record<string, boolean | GroupItem>>;
export declare const mapTree: (item: TreeViewItem, groupKey: string, selected: Record<string, Record<string, boolean | GroupItem>>) => TreeViewItem;
export declare const onTreeCheck: (e: ChangeEvent, treeViewItem: TreeViewItem, tree: TreeViewItem[]) => any;
export {};
